// reg16x8.v
`timescale  1 ns /  1 ps

module reg16x32( clk, nreset, wr_en, rd_en, addr, data_in, data_out, reg_0_out, reg_1_in); 
  
  
//Inputs Declarations 
input  clk;             //Clock
input  nreset;          //active low reset  
input  wr_en;           //Write Enable 
input  rd_en;           //Read Enable 
input  [3:0] addr;      //Address Width 
input  [31:0] data_in;   //Data Input 

input [31:0] reg_1_in;

//output Declarations 
output [31:0] data_out;  //Data Output 
output [31:0] reg_0_out;
  
//reg Declarations 
reg [31:0] mem [15:0];    //Memory 
reg [31:0] data_out;     //Data Output 

assign reg_0_out = mem[0];

//Generation of data_out 
always @(posedge clk, negedge nreset) 
    begin : READ_GEN 
        if(nreset == 1'b0)
            begin
                data_out <= 32'h00000000;
            end
        else if(rd_en)
            begin  
                case(addr)
                  4'b0001: data_out <= reg_1_in;
                  default: data_out <= mem[addr]; 
                endcase
            end         
    end 

//Generation Writing data into memory 
always @(posedge clk, negedge nreset) 
    begin : WRITE_GEN 
        if(nreset == 1'b0)
            begin
                mem[addr] <= 32'h00000000;
            end
        else if(wr_en)
            begin
                case(addr)
                  4'b0001: mem[addr] <= reg_1_in;
                  default: mem[addr] <= data_in;
                endcase
            end
  	 
end
  
endmodule