`timescale 1 ns/100 ps
/*-------------------------------------------------------------------------------
-- Title      : Custom APB slave
-------------------------------------------------------------------------------
-- File       : reg_apb_wrp.v
-- Author     : Mir Ali
-- Company    : Actel Corporation
-- Device     : SmartFusion 
-- Standard   : Verilog
-------------------------------------------------------------------------------
-- Description: This code creates an APB slave wrapper on a 32x8 memory block(no wait state)
-- It decodes the APB lite signals and then do the required action on the memory
-------------------------------------------------------------------------------
-- Copyright (c) 2010   Actel Corporation
--                      All rights reserved.
-------------------------------------------------------------------------------
-- Revisions  : V2.0 
-------------------------------------------------------------------------------*/


module reg_apb_wrp(
  PCLK,
  PENABLE,
  PSEL,
  PRESERN,
  PWRITE,
  PREADY,
  PSLVERR,
  PADDR,
  PWDATA,
  PRDATA,
  LED,
  SW);


input PCLK,PENABLE, PSEL, PRESERN, PWRITE;
input  [31:0] PWDATA;
input  [7:0] PADDR;
input  [1:0] SW;
output [31:0] PRDATA;
output PREADY, PSLVERR;
output [7:0] LED;

wire rd_enable;
wire wr_enable;
wire [31:0] reg_led;
wire [31:0] reg_sw;

assign wr_enable = (PENABLE &&  PWRITE && PSEL);
assign rd_enable = (!PWRITE && PSEL); //Data is ready during first cycle to make it availble on the bus when PENABLE is asserted
assign reg_sw[1:0] = SW;

reg16x32 reg16x32_0 (.clk(PCLK), .nreset(PRESERN), .wr_en(wr_enable), 
        .rd_en(rd_enable), .addr(PADDR[5:2]), .data_in(PWDATA), .data_out(PRDATA),
        .reg_0_out(reg_led), .reg_1_in(reg_sw));
enc3to8 enc3to8_0 (.data(reg_led[2:0]), .y(LED [7:0]));

        
assign PREADY = 1'b1; 
assign PSLVERR = 1'b0;         
    
endmodule